Official Octane Bindings for Python
===================================

A Python library for Octane's API.


Setup
-----

You can install this package by using the pip tool and installing:

    $ pip install octane


Setting up a Octane Account
---------------------------

Sign up for Octane at https://cloud.getoctane.io/register.

Using the Octane API
--------------------

Documentation for the python bindings can be found alongside Octane's other bindings here:

- https://getoctane.io/docs
- https://getoctane.io/docs/api/python

In the standard documentation (the first link), most of the reference pages will have examples in Octane's official bindings (including Python). Just click on the Python tab to get the relevant documentation.

In the full API reference for python (the second link), the right half of the page will provide example requests and responses for various API calls.
